@@ -27,11 +27,25 @@ log = logging.getLogger(__name__)
 class ComplexEncoder(json.JSONEncoder):
 
     def default(self, obj):
-        try:
-            return super(ComplexEncoder, obj).default(obj)
 
-        except TypeError:
-            return str(obj)
+        log.debug('encoding {0}, a {1}.'.format(obj, type(obj)))
+
+        if hasattr(obj, '__jsondata__'):
+            log.debug('extracting jsondata...')
+            return self.default(obj.__jsondata__)
+
+        try:
+            return json.JSONEncoder.default(self, obj)
+
+        except TypeError as ex:
+
+            log.exception(ex)
+
+            if isinstance(obj, datetime.datetime):
+                return str(obj)
+
+            else:
+                raise
 
 class ConfigWrapper(object):
 
@@ -389,8 +403,13 @@ class ConfigWrapper(object):
         # Give jinja a reference to the configwrapper.
         j.globals['cw'] = self
 
+        self.add_more_stuff_to_jinja2_globals()
+
         return j
 
+    def add_more_stuff_to_jinja2_globals(self):
+        log.info("Nothing extra to add...")
+
     def get_jinja2_environment(self):
 
         if not self.jinja2_environment:
